****** Welcome to Stata 17! ******

**# Bayesian econometrics
**## Bayesian VAR

webuse usmacro, clear
bayes: var inflation ogap fedfunds

bayes, saving(bvarsim1): var inflation ogap fedfunds, lags(1/1)
estimates store lag1
bayes, saving(bvarsim2): var inflation ogap fedfunds
estimates store lag2
bayes, saving(bvarsim3): var inflation ogap fedfunds, lags(1/3)
estimates store lag3
bayes, saving(bvarsim4): var inflation ogap fedfunds, lags(1/4)
estimates store lag4
bayestest model lag1 lag2 lag3 lag4

bayesvarstable

bayesfcast compute f_, step(10)
bayesfcast graph f_inflation f_ogap f_fedfunds

bayesirf create birf, set(birfex, replace)
bayesirf graph irf, impulse(fedfunds)

bayesirf graph fevd

bayesirf table irf fevd, impulse(fedfunds) response(inflation) 

**## Bayes DSGE
webuse usmacro2, clear
bayes, prior({beta},  beta(95,5)) prior({kappa}, beta(30,70))  	///
       prior({delta}, beta(60,30)) prior({rhoz},  beta(10,10)) 	///
       prior({rhom},  beta(10,10)) rseed(17) :                 	///
         dsge (  x = F.x - (r - F.p - z), unobserved) 		///
              (  p = {beta}*F.p + {kappa}*x         ) 		///
              (  r = 1/{delta}*p + m                ) 		///
              (F.z = {rhoz}*z, state                ) 		///
              (F.m = {rhom}*m, state                )
bayes, saving(nk_mcmc.dta, replace)

bayesirf create nk_model, set(nk)
bayesirf graph irf, impulse(m) response(x p r m)

**# Bayesian panel-data/multilevel models
**## xtmlogit
webuse estatus, clear
xtset id
xtmlogit estatus i.hhchild hhincome, rrr 
margins hhchild, at(hhincome=(20(20)100))
marginsplot, by(_predict, label("Out of labor force" "Unemployed" "Employed")) ///
byopts(rows(1) title("Marginal probabilities of employment status")) ///
legend(order(4 "Child under 5 at home" 3 "No child under 5 at home"))
xtmlogit estatus i.hhchild hhincome, fe
bayes, prior({Out_of_labor_force:1.hhchild}, normal(.5,.5)): ///
xtmlogit estatus i.hhchild hhincome

**## Bayesian multilevel model
twoway (function y1 = -12.84796 + 5.977761*x, range(3 30) lwidth(thick)) ///
(function y2 = 78.42872/(1+.0634061*78.42872*exp(-.2208688*x)), ///
range(3 30) lwidth(thick)), legend(order(1 "Wing length" 2 "Weight")) ///
xtitle("Time (in weeks)")

webuse chicks, clear
rename y1 wing
rename y2 weight
bayesmh (wing = ({U[id]} + time*{V[id]}))                                 	///
        (weight = ({C[id]}/(1+{d}*{C[id]}*exp(-{B[id]}*time)))),            	///
likelihood(mvnormal({Sigma0,m}))                       				///
prior({U V C B}, mvnormal(4,{u},{v},{c},{b},{Sigma,m})) 			///
prior({u v c b},  normal(0, 100)) prior({Sigma0,m}, iwishart(2,3,I(2)))		///
prior({Sigma,m},  iwishart(4,5,I(4))) prior({d}, exp(1))			///
block({d u v b c}, split) block({Sigma0,m} {Sigma,m}, gibbs split)		///
init({U[id] u} -10 {V[id] v} 10 {C[id] c} 100 {d} 1) mcmcsize(2500) rseed(17)

**# Survival models
**## Bayesian joint survival/ growth
webuse panss, clear
bayesmh (panss i.treat##i.week U[id]@1, likeli(norm({var}))) 			///
 (t1 i.treat U[id], likeli(stweibull({lnp}), failure(dropinf) ltrunc(t0))), 	///
 prior({panss:i.treat##i.week  _cons}, 		normal(0,10000)) 		///
 prior({U} ,					normal(0, {var_U})) 		///
 prior({t1:i.treat U  _cons}, 			normal(0,10000)) 		///
 prior({var_U} {var}, 				igamma(.01, .01)) 		///
 prior({lnp}, 					normal(0, 10000)) 		///
 block({panss:i.treat##i.week _cons})  block({t1: i.treat U _cons}) 	 	///
 block({var_U} {var}) thinning(5) burnin(10000)

reshape wide panss t0 t1 dropinf, i(id) j(week)
misstable patterns panss*, bypattern

**## stintcox
webuse bts, clear
stintcox age_mean i.male i.needle, interval(ltime rtime)
stintphplot, interval(ltime rtime) by(needle) adjustfor(age_mean i.male)
stcurve, survival
stcurve, survival at(needle=(0 1))

**# Lasso
**## BIC
webuse fakesurvey_vl, clear
vl rebuild
rename q104 y
global covariates $idemographics $ifactors##c.$vlcontinuous

lasso linear y $covariates, rseed(1234)

lasso linear y $covariates, selection(bic) rseed(1234)

bicplot

**## Clustered data
webuse regsmpl, clear
rename ttl_exp experience
rename black nocollege
rename not_smsa rural
global vars c.(age tenure experience) i.(rural south nocollege)
global covariates ($vars)##($vars)
lasso linear ln_wage $covariates, cluster(idcode) selection(bic) rseed(1234)

global vars2 c.(age experience) i.(rural south nocollege)
global controls ($vars2)##($vars2)
dsregress ln_wage tenure, controls($controls) vce(cluster idcode) selection(bic) ///
rseed(1234)

**## telasso
webuse cattaneo2, clear
global vars i.(mmarried mhisp fhisp foreign alcohol deadkids mrace frace ///
fbaby prenatal1) c.(mage medu fage fedu nprenatal monthslb order prenatal)
global controls ($vars)##($vars)
telasso (bweight $controls) (mbsmoke $controls), selection(bic) rseed(1234)

**# DID, trends
**## DID
webuse hospdd

didregress (satis) (procedure), group(hospital) time(month)
estat trendplots, omeans noxline
didregress (satis frequency) (procedure), group(hospital) time(month)

estat trendplots
estat ptrends
estat granger

**## nptrend
webuse migraine, clear
nptrend relief, group(dose) carmitage
replace dose = dose/10
nptrend relief, group(dose) carmitage scoregroup(1 4 9 16)
nptrend relief, group(dose) carmitage notable exact(, rseed(1234))

**# Meta-analysis, ziologit
**## meta-analysis
webuse bcgset, clear
meta forestplot
/* making effect size positive just to make galbraith easier to interpret - you
wouldn't actually do this! */
replace _meta_es = _meta_es*-1 
meta galbraithplot
meta galbraithplot, mlabel(author)
meta forestplot, leaveoneout common(iv)

**## MV meta-analysis
webuse periodontal, clear
meta mvregress y1 y2, wcovvariables(v11 v12 v22)
estat heterogeneity
meta mvregress y1 y2 = pubyear, wcovvariables(v11 v12 v22)

**## ziologit
webuse tobacco, clear
ziologit tobacco income i.female, inflate(income i.parent)

margins, at(income=(0(5)20))
marginsplot, legend(order(5 "0 cigarettes" 6 "1–7 cigarettes/day" ///
7 "8–12 cigarettes/day" 8 ">12 cigarettes/day"))

margins parent, predict(ps) at(income=(0(5)20))
marginsplot, legend(order(3 "Parent doesn't smoke" 4 "Parent smokes"))

margins, predict(pcond1 outcome(0))	  	      	///
predict(pcond1 outcome(1)) 						///
predict(pcond1 outcome(2)) 						///
predict(pcond1 outcome(3)) at(income=(0(5)20))
marginsplot, legend(order(5 "0 cigarettes" 6 "1–7 cigarettes/day" ///
7 "8–12 cigarettes/day" 8 ">12 cigarettes/day"))

**# Customizable tables
**## table
webuse nlsw88, clear
table (smsa) (collgrad)
table () (collgrad), statistic(fvpercent smsa south) style(table-1)
table () (collgrad), statistic(fvpercent smsa south) ///
statistic(mean age wage) style(table-1)
table () (collgrad), statistic(fvpercent smsa south) ///
statistic(mean age wage) style(table-1) nformat(%5.2f)

table () (collgrad), command(regress wage age tenure i.union) ///
style(table-reg1-fv1) nformat(%5.2f)

table () (collgrad), command(_r_b _r_se: regress wage tenure i.union) ///
style(table-reg1-fv1) nformat(%5.2f)

table (colname result) (collgrad), command(_r_b _r_se: ///
regress wage tenure i.union) style(table-reg1-fv1) nformat(%5.2f)

table (colname result) (collgrad), command(_r_b _r_se: ///
regress wage tenure i.union) style(table-reg1-fv1) nformat(%5.2f)

**## collect
collect style cell cell_type[column-header item], halign(center)
collect style cell result[_r_se], sformat("(%s)")
collect style header result, level(hide)
collect style showbase off
collect style row stack, spacer
collect style cell border_block, border(right left, pattern(nil))
collect preview

collect style save mystyle, replace
webuse lbw, clear
table (colname result) (smoke), ///
command(_r_b _r_se: regress bwt age i.ht lwt) style(mystyle, override)

collect export mytable.pdf, replace
collect export mytable.docx, replace
collect export mytable.tex, replace

**## Daily profit report
/* this won't work, but you can still see how the code would work */
collect clear
use profits, clear
table () (Year), statistic(sum profit) nototals name(c1)
table () (Year) if Quarter==quarter(today()), ///
statistic(sum profit) nototals name(c2)
table () (Year) if month(Date)==month(today()) & day(Date)==day(today()), ///
statistic(sum profit) nototals name(c3)
collect combine newc = c1 c2 c3
collect style use profit, replace
collect label use profitlab, replace
collect layout (collection) (Year)






